##
##  librsvg.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_major   2.55
%define       V_minor   1

#   package information
Name:         librsvg
Summary:      Scalable Vector Graphics (SVG) Library
URL:          http://librsvg.sourceforge.net/
Vendor:       The GNOME Project
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Graphics
License:      LGPL
Version:      %{V_major}.%{V_minor}
Release:      20220913

#   list of sources
Source0:      http://ftp.gnome.org/pub/GNOME/sources/librsvg/%{V_major}/librsvg-%{version}.tar.xz
Patch0:       librsvg.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, pkgconfig, rust, docutils
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  libxml, cairo, libcroco, glib, pango, popt, gdk-pixbuf
PreReq:       libxml, cairo, libcroco, glib, pango, popt, gdk-pixbuf

%description
    LibRSVG is a rendering library for Scalable Vector Graphics (SVG).

%track
    prog librsvg:major = {
        version   = %{V_major}
        url       = http://ftp.gnome.org/pub/GNOME/sources/librsvg/
        regex     = (\d+\.\d+)/
    }
    prog librsvg:full = {
        version   = %{version}
        url       = http://ftp.gnome.org/pub/GNOME/sources/librsvg/%{V_major}/
        regex     = librsvg-(__VER__)\.tar\.xz
    }

%prep
    %setup -q
    %patch -p0

%build
    export HOME=`pwd`
    cargo update
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    GI_DOCGEN="true" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --disable-pixbuf-loader \
        --disable-gtk-doc \
        --disable-introspection \
        --disable-shared
    %{l_make} %{l_mflags}

%install
    export HOME=`pwd`
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/gtk-doc
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/doc
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/locale
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/lib/mozilla
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/lib/gtk-2.0
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std}

%files -f files

%clean

